# SubmitDataQueryRequestSourceData

Specify the source that data queries run against. Currently, the only valid value is `LIVE`, representing the live transactional databases at Zuora (Data Query Live). 

## Enum

* `LIVE` (value: `'LIVE'`)

* `WAREHOUSE` (value: `'WAREHOUSE'`)

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


